@@ -96,7 +96,7 @@ def addSpells(spells):
 
 @task()
 def addTrans(trans):
-    ts = Transcription(pk=t[0],Transcription = t[1]) for t in trans]
+    ts = [Transcription(pk=t[0],Transcription = t[1]) for t in trans]
     Transcription.objects.bulk_create(ts)
 
 
