@@ -2,7 +2,7 @@ import os
 
 from django.db.models import Sum
 
-from .models import FreqDict,Lemma,WordForm,Orthography,Transcription
+from .models import Lemma,WordForm,Orthography,Transcription
 
 
 def checkDict(freqDict):
